@@ -26,6 +26,9 @@ FAILEDOPERATION_AGENOTACHIEVENORMALLEGAL = 'FailedOperation.AgeNotAchieveNormalL
 # 鉴权失败。
 FAILEDOPERATION_AUTHFAIL = 'FailedOperation.AuthFail'
 
+# 当选择“企业实名认证（信任第三方认证源）”时，请先使用“同步企业信息”接口，同步企业名称、统一社会信用代码、法人姓名。
+FAILEDOPERATION_ERRNOTSYNCPROXYORGANIZATION = 'FailedOperation.ErrNotSyncProxyOrganization'
+
 # 存在同名印章。
 FAILEDOPERATION_EXISTSAMESEALNAME = 'FailedOperation.ExistSameSealName'
 
@@ -35,6 +38,12 @@ FAILEDOPERATION_FLOWNUMEXCEED = 'FailedOperation.FlowNumExceed'
 # 已授权。
 FAILEDOPERATION_HASAUTHORIZED = 'FailedOperation.HasAuthorized'
 
+# 自动签许可额度不足
+FAILEDOPERATION_LICENSENOQUOTA = 'FailedOperation.LicenseNoQuota'
+
+# 无角色授权，请确认数据是否存在
+FAILEDOPERATION_NOROLEAUTH = 'FailedOperation.NoRoleAuth'
+
 # 当前合同状态无法进行签署审批。
 FAILEDOPERATION_NOTAVAILABLESIGNREVIEW = 'FailedOperation.NotAvailableSignReview'
 
@@ -50,6 +59,12 @@ FAILEDOPERATION_QRCODETEMPLATEID = 'FailedOperation.QrCodeTemplateId'
 # 员工已实名。
 FAILEDOPERATION_STAFFALREADYVERIFY = 'FailedOperation.StaffAlreadyVerify'
 
+# 无法撤销，用户已开通自动签。
+FAILEDOPERATION_USERAUTOSIGNENABLEALREADY = 'FailedOperation.UserAutoSignEnableAlready'
+
+# 无法撤销，用户未生成开通链接。
+FAILEDOPERATION_USERAUTOSIGNENABLEURLNOTEXIST = 'FailedOperation.UserAutoSignEnableUrlNotExist'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -77,6 +92,9 @@ INTERNALERROR_DECRYPTION = 'InternalError.Decryption'
 # 依赖的其他api出错。
 INTERNALERROR_DEPENDSAPI = 'InternalError.DependsApi'
 
+# 数据库异常。
+INTERNALERROR_DEPENDSDB = 'InternalError.DependsDb'
+
 # 加密错误。
 INTERNALERROR_ENCRYPTION = 'InternalError.Encryption'
 
@@ -107,6 +125,12 @@ INVALIDPARAMETER_APPLICATION = 'InvalidParameter.Application'
 # 参数错误，不合法的签署人类型，请修改后重试。
 INVALIDPARAMETER_APPROVERTYPE = 'InvalidParameter.ApproverType'
 
+# ApproverVerifyType参数值非法
+INVALIDPARAMETER_APPROVERVERIFYTYPE = 'InvalidParameter.ApproverVerifyType'
+
+# 不合法的授权方式, 请重新指定授权方式后发起
+INVALIDPARAMETER_AUTHORIZATIONTYPE = 'InvalidParameter.AuthorizationType'
+
 # 重复添加签署人。
 INVALIDPARAMETER_BIZAPPROVERALREADYEXISTS = 'InvalidParameter.BizApproverAlreadyExists'
 
@@ -116,6 +140,9 @@ INVALIDPARAMETER_BUSINESSLICENSE = 'InvalidParameter.BusinessLicense'
 # 撤销理由填写格式错误。
 INVALIDPARAMETER_CANCELREASON = 'InvalidParameter.CancelReason'
 
+# 证件号码错误。
+INVALIDPARAMETER_CARDNUMBER = 'InvalidParameter.CardNumber'
+
 # 证件类型错误。
 INVALIDPARAMETER_CARDTYPE = 'InvalidParameter.CardType'
 
@@ -188,6 +215,12 @@ INVALIDPARAMETER_GENERATETYPE = 'InvalidParameter.GenerateType'
 # 图片不正确。
 INVALIDPARAMETER_IMAGE = 'InvalidParameter.Image'
 
+# Id不存在或者符合规范。
+INVALIDPARAMETER_INVALIDID = 'InvalidParameter.InvalidId'
+
+# 参数Limit不正确
+INVALIDPARAMETER_LIMIT = 'InvalidParameter.Limit'
+
 # 印章名称长度超出。
 INVALIDPARAMETER_LIMITSEALNAME = 'InvalidParameter.LimitSealName'
 
@@ -206,6 +239,9 @@ INVALIDPARAMETER_NAME = 'InvalidParameter.Name'
 # 不支持的手机号。
 INVALIDPARAMETER_NONSUPPORTMOBILE = 'InvalidParameter.NonsupportMobile'
 
+# 参数Offset不正确
+INVALIDPARAMETER_OFFSET = 'InvalidParameter.Offset'
+
 # OpenId不合法。
 INVALIDPARAMETER_OPENID = 'InvalidParameter.OpenId'
 
@@ -218,24 +254,45 @@ INVALIDPARAMETER_ORGANIZATIONNAME = 'InvalidParameter.OrganizationName'
 # 参数错误。
 INVALIDPARAMETER_PARAMERROR = 'InvalidParameter.ParamError'
 
-# 文件内容敏感信息。
+# 资源类型错误。
+INVALIDPARAMETER_RESOURCETYPE = 'InvalidParameter.ResourceType'
+
+# 角色ID不正确
+INVALIDPARAMETER_ROLEID = 'InvalidParameter.RoleId'
+
+# 上传的文件包含敏感（不合规）的内容，请确认。
 INVALIDPARAMETER_SENSITIVEFILECONTENT = 'InvalidParameter.SensitiveFileContent'
 
 # 参数错误，不合法的签署控件类型，请修改后重试。
 INVALIDPARAMETER_SIGNCOMPONENTTYPE = 'InvalidParameter.SignComponentType'
 
+# 类型不支持。
+INVALIDPARAMETER_SIGNCOMPONENTS = 'InvalidParameter.SignComponents'
+
 # 状态异常。
 INVALIDPARAMETER_STATUS = 'InvalidParameter.Status'
 
+# 统一社会信用代码不符合要求
+INVALIDPARAMETER_UNIFORMSOCIALCREDITCODE = 'InvalidParameter.UniformSocialCreditCode'
+
 # 参数错误，不合法的签署顺序，请检查后重试。
 INVALIDPARAMETER_UNORDERED = 'InvalidParameter.Unordered'
 
 # 参数错误，不支持的控件类型，请检查后重试。
 INVALIDPARAMETER_UNSUPPORTEDCOMPONENTTYPE = 'InvalidParameter.UnsupportedComponentType'
 
+# 流程id不存在。
+INVALIDPARAMETER_FFOWIDS = 'InvalidParameter.fFowIds'
+
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
+# 非法的套餐类型
+INVALIDPARAMETERVALUE_INVALIDQUOTATYPE = 'InvalidParameterValue.InvalidQuotaType'
+
+# 非法的时间参数
+INVALIDPARAMETERVALUE_INVALIDTIME = 'InvalidParameterValue.InvalidTime'
+
 # 超过配额限制。
 LIMITEXCEEDED = 'LimitExceeded'
 
@@ -290,6 +347,9 @@ MISSINGPARAMETER_ORGANIZATIONID = 'MissingParameter.OrganizationId'
 # ProxyOperatorOpenId不存在。
 MISSINGPARAMETER_PROXYOPERATOROPENID = 'MissingParameter.ProxyOperatorOpenId'
 
+# 资源名称错误。
+MISSINGPARAMETER_RESOURCENAME = 'MissingParameter.ResourceName'
+
 # 印章ID为空。
 MISSINGPARAMETER_SEALID = 'MissingParameter.SealId'
 
@@ -305,12 +365,21 @@ MISSINGPARAMETER_SIGNCOMPONENTS = 'MissingParameter.SignComponents'
 # 缺少模板参数。
 MISSINGPARAMETER_TEMPLATES = 'MissingParameter.Templates'
 
+# 缺少用户ID参数
+MISSINGPARAMETER_USERID = 'MissingParameter.UserId'
+
 # OpenId不存在。
 MISSINGPARAMETER_USEROPENID = 'MissingParameter.UserOpenId'
 
 # 操作被拒绝。
 OPERATIONDENIED = 'OperationDenied'
 
+# 相关资源已经存证, 无法在创建新的相关资源
+OPERATIONDENIED_ALREADYHAS = 'OperationDenied.AlreadyHas'
+
+# 参与人信息有重复
+OPERATIONDENIED_APPROVERREPEAT = 'OperationDenied.ApproverRepeat'
+
 # 不支持的可见性标识。
 OPERATIONDENIED_AUTHTAG = 'OperationDenied.AuthTag'
 
@@ -326,6 +395,9 @@ OPERATIONDENIED_DOWNLOADMORETHANONE = 'OperationDenied.DownLoadMoreThanOne'
 # 无资源访问权限。
 OPERATIONDENIED_ERRNORESOURCEACCESS = 'OperationDenied.ErrNoResourceAccess'
 
+# 第三方应用平台未开通“平台子客企业实名认证（信任第三方认证源）”能力
+OPERATIONDENIED_ERRNOTOPENWEAKAUTHORIZATION = 'OperationDenied.ErrNotOpenWeakAuthorization'
+
 # 文件已删除。
 OPERATIONDENIED_FILEDELETED = 'OperationDenied.FileDeleted'
 
@@ -344,18 +416,27 @@ OPERATIONDENIED_INVALIDAPPROVERAGE = 'OperationDenied.InvalidApproverAge'
 # 没有API权限。
 OPERATIONDENIED_NOAPIAUTH = 'OperationDenied.NoApiAuth'
 
+# 企业暂未开通手机号验证身份的服务，请在企业中心开通再使用
+OPERATIONDENIED_NOAPPROVERMOBILECHECKPERMISSION = 'OperationDenied.NoApproverMobileCheckPermission'
+
 # 无权操作合同。
 OPERATIONDENIED_NOFLOWPERMISSION = 'OperationDenied.NoFlowPermission'
 
 # 未通过个人实名。
 OPERATIONDENIED_NOIDENTITYVERIFY = 'OperationDenied.NoIdentityVerify'
 
+# 无权限进行操作
+OPERATIONDENIED_NOPERMISSIONUSERESOURCE = 'OperationDenied.NoPermissionUseResource'
+
 # 流程配额不足。
 OPERATIONDENIED_NOQUOTA = 'OperationDenied.NoQuota'
 
 # 不属于企业超管或者法人。
 OPERATIONDENIED_NOTBELONGSUPERADMINORLEGALPERSON = 'OperationDenied.NotBelongSuperAdminOrLegalPerson'
 
+# 不支持的企业类型
+OPERATIONDENIED_NOTSUPPORTORGTYPE = 'OperationDenied.NotSupportOrgType'
+
 # 操作类型不支持。
 OPERATIONDENIED_OPERATETYPE = 'OperationDenied.OperateType'
 
@@ -368,13 +449,19 @@ OPERATIONDENIED_OUTQUERYLIMIT = 'OperationDenied.OutQueryLimit'
 # 当前企业员工没有开通境外签署能力。
 OPERATIONDENIED_OVERSEAABILITYNOTOPEN = 'OperationDenied.OverseaAbilityNotOpen'
 
+# 该用户已关闭或者未开启自动签服务
+OPERATIONDENIED_PERSONNOOPENSERVERSIGN = 'OperationDenied.PersonNoOpenServerSign'
+
 # 出证计费额度不足。
 OPERATIONDENIED_PROVENOQUOTA = 'OperationDenied.ProveNoQuota'
 
+# 必填控件未填
+OPERATIONDENIED_REQUIREDCOMPONENTNOTFILL = 'OperationDenied.RequiredComponentNotFill'
+
 # 用户不归属于当前企业，无法操作，请检查后重试。
 OPERATIONDENIED_USERNOTINORGANIZATION = 'OperationDenied.UserNotInOrganization'
 
-# 未开通功能白名单，请联系客服处理。
+# 接口功能暂未开放，请联系客户经理申请白名单使用
 OPERATIONDENIED_WHITELISTFORBID = 'OperationDenied.WhiteListForbid'
 
 # 资源不存在。
@@ -404,6 +491,9 @@ RESOURCENOTFOUND_FLOWAPPROVERS = 'ResourceNotFound.FlowApprovers'
 # 合同组不存在。
 RESOURCENOTFOUND_FLOWGROUP = 'ResourceNotFound.FlowGroup'
 
+# 应用号不存在
+RESOURCENOTFOUND_NOTEXISTAPPLICATION = 'ResourceNotFound.NotExistApplication'
+
 # 机构不存在。
 RESOURCENOTFOUND_ORGANIZATION = 'ResourceNotFound.Organization'
 
